ExLaunchDark.LDAdapter (ex_launch_dark v1.1.2)
View SourceAdapter module for LaunchDarkly feature flag evaluations.
Summary
Functions
Retrieves the state of all feature flags for a given context.
Retrieves the value of a single feature flag for a given context.
Tracks a custom event for a given context.
Functions
@spec get_all_flags(atom(), ExLaunchDark.LDContextStruct.t()) :: :ldclient_eval.feature_flags_state()
Retrieves the state of all feature flags for a given context.
@spec get_feature_flag_value( atom(), String.t(), ExLaunchDark.LDContextStruct.t(), any() ) :: {:ok, any(), atom()} | {:error, any(), atom()} | {:null, any(), atom()}
Retrieves the value of a single feature flag for a given context.
@spec track_event( atom(), String.t(), ExLaunchDark.LDContextStruct.t(), :ldclient_event.event_data() ) :: :ok
Tracks a custom event for a given context.