ExLaunchDark.LDAdapter (ex_launch_dark v1.2.4)

Adapter module for LaunchDarkly feature flag evaluations.

Summary

Functions

Retrieves the state of all feature flags for a given context.

Retrieves the value of a single feature flag for a given context.

Normalises a flag key by converting it to lowercase and replacing underscores with hyphens.

Tracks a custom event for a given context.

Functions

get_all_flags(project_id, ld_context)

Retrieves the state of all feature flags for a given context.

get_feature_flag_value(project_id, flag_key, ld_context, default_value)

Retrieves the value of a single feature flag for a given context.

normalise(s)

@spec normalise(String.t()) :: String.t()

Normalises a flag key by converting it to lowercase and replacing underscores with hyphens.

track_event(project_id, event_name, ld_context, event_data \\ %{})

Tracks a custom event for a given context.